declare const hashSecret: (secret: Buffer) => string;
interface GenerateAPIKeyOptions {
    /** The prefix for your API key (e.g., `sk-myapp`) */
    keyPrefix: string;
    /** The desired length of the key ID (which is in base58). Defaults to 8. */
    keyIdLength?: number;
    /** The entropy of the secret in bits. Defaults to 128. */
    secretEntropy?: number;
}
interface APIKeyObject {
    /** A random identifier for this key. Not a secret. Should be stored in the DB. */
    keyId: string;
    /** A hash of the secret. Should be stored in the DB. */
    secretHash: string;
    /** The fully formed token to give to the API client */
    apiKey: string;
}
declare const generateAPIKey: ({ keyPrefix, keyIdLength, secretEntropy, }: GenerateAPIKeyOptions) => Promise<APIKeyObject>;
declare const extractKeyId: (apiKey: string) => string;
declare const extractSecret: (apiKey: string) => string;
declare const extractSecretAsBuffer: (apiKey: string) => Buffer;
declare const getAPIKeyObject: (apiKey: string) => APIKeyObject;
/**
 * Verify the client's provided API Key
 *
 * @param inputAPIKey - the client-provided API key
 * @param expectedSecretHash - the secret hash stored in the DB (base58 encoded)
 * @returns true if the API key is valid, false otherwise
 */
declare const checkAPIKey: (inputAPIKey: string, expectedSecretHash: string) => boolean;

export { APIKeyObject, GenerateAPIKeyOptions, checkAPIKey, extractKeyId, extractSecret, extractSecretAsBuffer, generateAPIKey, getAPIKeyObject, hashSecret };
