var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  checkAPIKey: () => checkAPIKey,
  extractKeyId: () => extractKeyId,
  extractSecret: () => extractSecret,
  extractSecretAsBuffer: () => extractSecretAsBuffer,
  generateAPIKey: () => generateAPIKey,
  getAPIKeyObject: () => getAPIKeyObject,
  hashSecret: () => hashSecret
});
module.exports = __toCommonJS(src_exports);
var import_node_crypto = require("crypto");
var import_node_util = require("util");
var import_base = require("@scure/base");
var randomBytesAsync = (0, import_node_util.promisify)(import_node_crypto.randomBytes);
var hashSecretAsBuffer = (secret) => (0, import_node_crypto.createHash)("sha256").update(secret).digest();
var hashSecret = (secret) => import_base.base58.encode(hashSecretAsBuffer(secret));
var generateAPIKey = async ({
  keyPrefix,
  keyIdLength = 8,
  secretEntropy = 128
}) => {
  if (secretEntropy % 8 !== 0) {
    throw new Error("`secretEntropy` must be a multiple of 8 so it can fill a byte string.");
  }
  if (!keyPrefix || keyPrefix.includes("_")) {
    throw new Error("You must provide a `keyPrefix`, and it must not include `_` characters.");
  }
  const secretLength = secretEntropy / 8;
  const [keyIdBytes, secretBytes] = await Promise.all([
    randomBytesAsync(keyIdLength),
    randomBytesAsync(secretLength)
  ]);
  const keyId = import_base.base58.encode(keyIdBytes);
  const secret = import_base.base58.encode(secretBytes);
  const apiKey = `${keyPrefix}_${keyId}_${secret}`;
  const secretHash = hashSecret(secretBytes);
  return { keyId, secretHash, apiKey };
};
var extractParts = (apiKey) => {
  if (typeof apiKey !== "string") {
    throw new Error("apiKey must be a string");
  }
  const parts = apiKey.split("_");
  if (parts.length !== 3 || parts.some((part) => part.length < 1)) {
    throw new Error("Unexpected API key format. There should be 3 parts separate by `_`.");
  }
  return parts;
};
var extractKeyId = (apiKey) => extractParts(apiKey)[1];
var extractSecret = (apiKey) => extractParts(apiKey)[2];
var extractSecretAsBuffer = (apiKey) => Buffer.from(import_base.base58.decode(extractSecret(apiKey)));
var getAPIKeyObject = (apiKey) => ({
  keyId: extractKeyId(apiKey),
  secretHash: hashSecret(extractSecretAsBuffer(apiKey)),
  apiKey
});
var checkAPIKey = (inputAPIKey, expectedSecretHash) => {
  const inputSecretHashBuffer = hashSecretAsBuffer(extractSecretAsBuffer(inputAPIKey));
  const expectedSecretHashBuffer = Buffer.from(import_base.base58.decode(expectedSecretHash));
  return (0, import_node_crypto.timingSafeEqual)(expectedSecretHashBuffer, inputSecretHashBuffer);
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  checkAPIKey,
  extractKeyId,
  extractSecret,
  extractSecretAsBuffer,
  generateAPIKey,
  getAPIKeyObject,
  hashSecret
});
